%% Load the Robotics Toolbox into Matlab's path
run('robot-9.10/rvctools/startup_rvc.m') % you only have to run this once

%% Load the WAM model into the workspace
% load the 7-dof Barrett WAM model into the workspace.
mdl_wam

% mdl_wam creates a variable "wam", which represents a WAM arm
wam % output the arm to the command window
% wam is a SerialLink object, which has various functions and properties

% learn more about the variables and functions of a SerialLink object
% doc SerialLink -or- help SerialLink

%% Animate a trajectory using the model
n = wam.n; % number of joints
q0 = zeros(1, n); % home configuration
qf = rand(1, n)*2*pi; % final configuration
k = 25; % create k points on a path from q0 to qf

% generate a linear path between q0 and qf
Q = zeros(k, n);
for i = 1:n
    Q(:, i) = linspace(q0(i), qf(i), k);
end
% Q is now a k x n matrix representing a path in configuration space of
% the manipulator.  Each row in the matrix is a configuration along the
% path, where Q(1,:) is the initial configuration q0 and Q(k,:) is the
% final configuration qf.

% import from an external file instead
% Q = dlmread('Q.csv'); % help dlmread to learn more

% animate the trajectory of the robot arm --remember each row is a new pose
wam.plot(Q) % all SerialLink objects, like wam, have a plot function
% doc SerialLink.plot -or- help SerialLink.plot to learn more

%% Plot and save images to a folder
% wam.plot(Q, 'movie', 'wam_imgs') % save poses as PNGs in folder wam_imgs

%% Plot a single pose
% call plot with a 1 x n row vector for a single configuration
% wam.plot(q0)
% wam.plot(Q(1,:))

%% Done!
% open('robot.pdf') % robot.pdf has more info about the Robotics Toolbox. 

%% The UR5 manipulator
% The other model we'll be using is the Universal UR5 arm.  Uncomment the
% last line to load the UR5 model into the workspace (or write a new
% script) and try animating the UR5 using the lines above as reference.

% mdl_ur5